Struct shapes::Rect[][src]

pub struct Rect {
    pub pos: Point,
    pub size: Size,
}
A rectangle.

Fields

pos: Point

The position of the top left corner of the rectangle.

size: Size

The width and height of the rectangle.

Implementations

Returns the position of the bottom side of the rectangle.

Computes a rectangle with quadruple the surface area of self and with center (self.x, self.y).

Compute whether or not the point is inside the rectangle.

Create a rectangle that circumscribes the given circle.

Create a square rectangle with sides of length len and top left corner at pos.

Returns the position of the left side of the rectangle.

Computes a rectangle whose perimeter forms the inside edge of margin with size m for self.

Computes a rectangle translated (slid) in the direction of the vector a distance relative to the size of the rectangle. For example, self.relative([1.0, 1.0]) returns a rectangle one rectangle to the right and down from the original.

Returns the position of the right side of the rectangle.

Computes a scaled rectangle with the same position as self.

Returns the position of the top side of the rectangle.