[−][src]Struct shapes::Rect
A rectangle.
Fields
pos: PointThe position of the top left corner of the rectangle.
size: SizeThe width and height of the rectangle.
Implementations
impl Rect[src]
pub fn bottom(&self) -> Scalar[src]
Returns the position of the bottom side of the rectangle.
pub fn centered(self) -> Rect[src]
Computes a rectangle with quadruple the surface area of self and with center (self.x, self.y).
pub fn contains<T: Into<Point>>(&self, point: T) -> bool[src]
Compute whether or not the point is inside the rectangle.
pub fn new_circle<T: Into<Point>>(center: T, radius: Scalar) -> Rect[src]
Create a rectangle that circumscribes the given circle.
pub fn new_square<T: Into<Point>>(pos: T, len: Scalar) -> Rect[src]
Create a square rectangle with sides of length len and top left corner at pos.
pub fn left(&self) -> Scalar[src]
Returns the position of the left side of the rectangle.
pub fn margin(self, m: Scalar) -> Rect[src]
Computes a rectangle whose perimeter forms the inside edge of margin with size m for self.
pub fn relative<T: Into<Point>>(self, v: T) -> Rect[src]
Computes a rectangle translated (slid) in the direction of the vector a distance relative to the size of the rectangle. For example, self.relative([1.0, 1.0]) returns a rectangle one rectangle to the right and down from the original.
pub fn right(&self) -> Scalar[src]
Returns the position of the right side of the rectangle.
pub fn scaled<T: Into<Size>>(self, v: T) -> Rect[src]
Computes a scaled rectangle with the same position as self.
pub fn top(&self) -> Scalar[src]
Returns the position of the top side of the rectangle.